from PyPDF2 import PdfReader, PdfWriter 

def extract_pages(original_pdf_path, new_pdf_path, num_pages):
    """
    Extracts a specified number of pages from a given PDF file and creates a new PDF file.
    
    :param original_pdf_path: A string representing the path to the original PDF file.
    :param new_pdf_path: A string representing the path to the new PDF file.
    :param num_pages: An integer representing the number of pages to extract.
    
    :return: None
    
    This function uses the PdfReader class to read the original PDF file, and the PdfWriter class to create a new PDF file
    with the specified number of pages. If the number of pages to extract is greater than the total number of pages in
    the original PDF file, it extracts all the available pages.

    Exemple:
        >>> extract_pages('input.pdf', 'output.pdf', 10)
    """
    pdf = PdfReader(original_pdf_path)
    total_pages = len(pdf.pages)

    num_pages_to_extract = min(num_pages, total_pages)

    writer = PdfWriter()
    for page_num in range(num_pages_to_extract):
        writer.add_page(pdf.pages[page_num])

    with open(new_pdf_path, "wb") as new_pdf:
        writer.write(new_pdf)